==> haskell-uri-encode-1.5.0.5-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-encode
version: 1.5.0.5
id: uri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
key: uri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
license: BSD3
maintainer: code@silk.co
synopsis: Unicode aware uri-encoding.
description:
    Unicode aware uri-encoding.
category: Network, Web
author: Silk
exposed: True
indefinite: False
exposed-modules:
    Network.URI.Encode
abi: 00dcebfa14331afdbd5a4b608fd0f9bf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/uri-encode-1.5.0.5
hs-libraries: HSuri-encode-1.5.0.5-5Catwi4SdqWKkVHjt2pJ5W
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=ab32d4d3146164271ec97b5409cdba0c
haddock-interfaces: /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html: /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.5-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-encode
version: 1.5.0.5
id: uri-encode-1.5.0.5-9Wq32vfwOwB7VcJ61aInF0
key: uri-encode-1.5.0.5-9Wq32vfwOwB7VcJ61aInF0
license: BSD3
maintainer: code@silk.co
synopsis: Unicode aware uri-encoding.
description:
    Unicode aware uri-encoding.
category: Network, Web
author: Silk
exposed: True
indefinite: False
exposed-modules:
    Network.URI.Encode
abi: 916178a67852664e941a8d7186391822
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/uri-encode-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/uri-encode-1.5.0.5
hs-libraries: HSuri-encode-1.5.0.5-9Wq32vfwOwB7VcJ61aInF0
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ=17ff77631878cfceba90438df04f39d6
haddock-interfaces: /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html: /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
